@@ -21,46 +21,47 @@
 
 #include "kuiviewer_part.h"
 #include "kuiviewer_part.moc"
-#include <kaction.h>
-#include <kactioncollection.h>
-#include <kapplication.h>
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kdialog.h>
-#include <kiconloader.h>
-#include <kcomponentdata.h>
-#include <kio/netaccess.h>
-#include <kparts/genericfactory.h>
-#include <kstandardaction.h>
-#include <kstyle.h>
-#include <qmetaobject.h>
 
-#include <qclipboard.h>
-#include <qcursor.h>
-#include <qfile.h>
-#include <qobject.h>
-#include <qpixmap.h>
-#include <qstyle.h>
-#include <qstylefactory.h>
-#include <qvariant.h>
-#include <kvbox.h>
-#include <kglobal.h>
-#include <QFormBuilder>
-#include <kselectaction.h>
+// KDE
+#include <KActionCollection>
+#include <KSelectAction>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KIO/NetAccess>
+#include <KLocale>
+#include <KAboutData>
+#include <KPluginFactory>
+#include <KStyle>
+#include <KVBox>
+#include <KDebug>
+// Qt
+#include <QtDesigner/QFormBuilder>
+#include <QtGui/QApplication>
+#include <QtGui/QClipboard>
+#include <QtGui/QStyleFactory>
+#include <QtCore/QFile>
 
-typedef KParts::GenericFactory<KUIViewerPart> KUIViewerPartFactory;
-K_EXPORT_COMPONENT_FACTORY( libkuiviewerpart, KUIViewerPartFactory )
+
+K_PLUGIN_FACTORY( KUIViewerPartFactory, registerPlugin<KUIViewerPart>(); )
+K_EXPORT_PLUGIN( KUIViewerPartFactory(
+                    KAboutData("kuiviewerpart",
+                       0, ki18n("KUIViewerPart"),
+                       "0.1",
+                       ki18n("Displays Designer's UI files"),
+                       KAboutData::License_LGPL).
+                    addAuthor(ki18n("Richard Moore"), KLocalizedString(), "rich@kde.org").
+                    addAuthor(ki18n("Ian Reinhart Geiser"), KLocalizedString(), "geiseri@kde.org").
+                    setProgramIconName(QLatin1String( "kuiviewer" )).
+                    setCatalogName( "kuiviewer" )))
 
 KUIViewerPart::KUIViewerPart( QWidget *parentWidget,
-                                  QObject *parent,
-                                  const QStringList & /*args*/ )
+                              QObject *parent,
+                              const QVariantList &/*args*/ )
     : KParts::ReadOnlyPart(parent)
 {
     // we need an instance
     setComponentData( KUIViewerPartFactory::componentData() );
 
-    KGlobal::locale()->insertCatalog("kuiviewer");
-
     // this should be your custom internal widget
     m_widget = new KVBox( parentWidget );
 
@@ -108,19 +109,6 @@ KUIViewerPart::~KUIViewerPart()
 {
 }
 
-KAboutData *KUIViewerPart::createAboutData()
-{
-    // the non-i18n name here must be the same as the directory in
-    // which the part's rc file is installed ('partrcdir' in the
-    // Makefile)
-    KAboutData *aboutData = new KAboutData("kuiviewerpart", 0, ki18n("KUIViewerPart"), "0.1",
-					   ki18n("Displays Designer's UI files"),
-					   KAboutData::License_LGPL );
-    aboutData->addAuthor(ki18n("Richard Moore"), KLocalizedString(), "rich@kde.org");
-    aboutData->addAuthor(ki18n("Ian Reinhart Geiser"), KLocalizedString(), "geiseri@kde.org");
-    return aboutData;
-}
-
 bool KUIViewerPart::openFile()
 {
     // m_file is always local so we can use QFile on it
