@@ -30,6 +30,7 @@
 
 #include <QProcess>
 #include <QString>
+#include <QStringBuilder>
 #include <QMap>
 
 #include <kdebug.h>
@@ -93,7 +94,7 @@ static const char* pInfo[NUM_LANG_WITH_INFO]={
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;",
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;",
 "nplurals=2; plural=(n != 1);",
-"nplurals=2; plural=n != 1;",
+"nplurals=2; plural=(n != 1);",
 "nplurals=2; plural=(n != 1);",
 "nplurals=2; plural=(n != 1);",
 "nplurals=2; plural=(n != 1);",
@@ -107,15 +108,15 @@ static const char* pInfo[NUM_LANG_WITH_INFO]={
 "nplurals=3; plural=n==1 ? 0 : n==2 ? 1 : 2;",
 "nplurals=2; plural=(n != 1);",
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);",
-"nplurals=1; plural=0;",
+"nplurals=2; plural=(n != 1);",
 "nplurals=2; plural=(n != 1);",
 "nplurals=1; plural=0;",
 "nplurals=1; plural=0;",
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);",
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);",
-"nplurals=2; plural=n != 1;",
 "nplurals=2; plural=(n != 1);",
-"nplurals=2; plural=n != 1;",
+"nplurals=2; plural=(n != 1);",
+"nplurals=2; plural=(n != 1);",
 "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);",
 "nplurals=2; plural=(n != 1);",
 "nplurals=2; plural=(n > 1);",
@@ -170,6 +171,7 @@ QString GNUPluralForms(const QString& lang)
 
     //BEGIN alternative
     // NOTE does this work under M$ OS?
+    qWarning()<<"gonna call msginit";
     QString def="nplurals=2; plural=n != 1;";
 
     QStringList arguments;
@@ -201,6 +203,7 @@ QString GNUPluralForms(const QString& lang)
                    "\"PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\\n\"\n"
                    "\"Last-Translator: FULL NAME <EMAIL@ADDRESS>\\n\"\n"
                    "\"Language-Team: LANGUAGE <LL@li.org>\\n\"\n"
+                   "\"Language: LL\\n\"\n"
                    "\"MIME-Version: 1.0\\n\"\n"
                    "\"Content-Type: text/plain; charset=UTF-8\\n\"\n"
                    "\"Content-Transfer-Encoding: ENCODING\\n\"\n"
@@ -242,6 +245,7 @@ void updateHeader(QString& header,
                   int& numberOfPluralForms,
                   const QString& CatalogProjectId,
                   bool generatedFromDocbook,
+                  bool belongsToProject,
                   bool forSaving)
 {
     QStringList headerList(header.split('\n',QString::SkipEmptyParts));
@@ -250,16 +254,18 @@ void updateHeader(QString& header,
 //BEGIN header itself
     QStringList::Iterator it,ait;
     QString temp;
+    QString authorNameEmail;
 
     bool found=false;
-    temp="Last-Translator: "+Settings::authorName();
+    authorNameEmail=Settings::authorName();
     if (!Settings::authorEmail().isEmpty())
-        temp+=(" <"+Settings::authorEmail()+'>');
-    temp+="\\n";
+        authorNameEmail+=(" <"%Settings::authorEmail()%'>');
+    temp="Last-Translator: "%authorNameEmail%"\\n";
 
+    QRegExp lt("^ *Last-Translator:.*");
     for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
     {
-        if (it->contains(QRegExp("^ *Last-Translator:.*")))
+        if (it->contains(lt))
         {
             if (forSaving) *it = temp;
             found=true;
@@ -269,23 +275,22 @@ void updateHeader(QString& header,
         headerList.append(temp);
 
     QString dateTimeString = KDateTime::currentLocalDateTime().toString("%Y-%m-%d %H:%M%z");
-    temp="PO-Revision-Date: "+dateTimeString+"\\n";
+    temp="PO-Revision-Date: "%dateTimeString%"\\n";
+    QRegExp poRevDate("^ *PO-Revision-Date:.*");
     for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
     {
-        found=it->contains(QRegExp("^ *PO-Revision-Date:.*"));
+        found=it->contains(poRevDate);
         if (found && forSaving) *it = temp;
     }
     if (KDE_ISUNLIKELY( !found ))
         headerList.append(temp);
 
-    temp="Project-Id-Version: "+CatalogProjectId+"\\n";
-    temp.remove(".pot");
-    temp.remove(".po");
+    temp="Project-Id-Version: "%CatalogProjectId%"\\n";
     //temp.replace( "@PACKAGE@", packageName());
-
+    QRegExp projectIdVer("^ *Project-Id-Version:.*");
     for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
     {
-        found=it->contains(QRegExp("^ *Project-Id-Version:.*"));
+        found=it->contains(projectIdVer);
         if (found && it->contains("PACKAGE VERSION"))
             *it = temp;
     }
@@ -299,7 +304,12 @@ void updateHeader(QString& header,
     QString language; //initialized with preexisting value or later
     QString mailingList; //initialized with preexisting value or later
 
-    KConfig allLanguagesConfig("all_languages", KConfig::NoGlobals, "locale"); allLanguagesConfig.setLocale(QString());
+    static KConfig* allLanguagesConfig=0;
+    if (!allLanguagesConfig)
+    {
+      allLanguagesConfig = new KConfig("all_languages", KConfig::NoGlobals, "locale");
+      allLanguagesConfig->setLocale(QString());
+    }
     QRegExp langTeamRegExp("^ *Language-Team:.*");
     for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
     {
@@ -310,7 +320,7 @@ void updateHeader(QString& header,
             QMap<QString,QString> map;
             foreach (const QString &runningLangCode, KGlobal::locale()->allLanguagesList())
             {
-                KConfigGroup cg(&allLanguagesConfig, runningLangCode);
+                KConfigGroup cg(allLanguagesConfig, runningLangCode);
                 map[cg.readEntry("Name")]=runningLangCode;
             }
             if (map.size()<16) //may be just "en_US" and ""
@@ -334,29 +344,40 @@ void updateHeader(QString& header,
     if (language.isEmpty())
     {
         //language=locale.languageCodeToName(d->_langCode);
-        KConfigGroup cg(&allLanguagesConfig, langCode);
+        KConfigGroup cg(allLanguagesConfig, langCode);
         language=cg.readEntry("Name");
         if (language.isEmpty())
             language=langCode;
     }
 
-    if (mailingList.isEmpty())
+    if (mailingList.isEmpty() || belongsToProject)
     {
         if (Project::instance()->isLoaded())
             mailingList=Project::instance()->mailingList();
-        else
+        else //if (mailingList.isEmpty())
             mailingList=Settings::defaultMailingList();
     }
 
 
-    temp="Language-Team: "+language+" <"+mailingList+'>';
-    temp+="\\n";
 
+    temp="Language-Team: "%language%" <"%mailingList%'>';
+    temp+="\\n";
     if (KDE_ISLIKELY( found ))
         (*ait) = temp;
     else
         headerList.append(temp);
 
+    QRegExp langCodeRegExp("^ *Language: *([^ \\\\]*)");
+    temp="Language: "%langCode%"\\n";
+    for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
+    {
+        found=(langCodeRegExp.indexIn(*it)!=-1);
+        if (found && langCodeRegExp.cap(1).isEmpty())
+            *it=temp;
+        //if (found) qWarning()<<"got explicit lang code:"<<langCodeRegExp.cap(1);
+    }
+    if (KDE_ISUNLIKELY( !found ))
+        headerList.append(temp);
 
     temp="Content-Type: text/plain; charset=UTF-8\\n";
     for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
@@ -376,17 +397,6 @@ void updateHeader(QString& header,
     if (!found)
         headerList.append(temp);
 
-    temp="X-Generator: Lokalize %1\\n";
-    temp=temp.arg(LOKALIZE_VERSION);
-
-    for ( it = headerList.begin(),found=false; it != headerList.end()&& !found; ++it )
-    {
-        found=it->contains(QRegExp("^ *X-Generator:.*"));
-        if (found) *it = temp;
-    }
-    if (KDE_ISUNLIKELY( !found ))
-        headerList.append(temp);
-
     // ensure MIME-Version header
     temp="MIME-Version: 1.0\\n";
     for ( it = headerList.begin(),found=false; it != headerList.end()&& !found; ++it )
@@ -444,6 +454,17 @@ void updateHeader(QString& header,
             headerList.append(QString("Plural-Forms: %1\\n").arg(t));
     }
 
+    temp="X-Generator: Lokalize %1\\n";
+    temp=temp.arg(LOKALIZE_VERSION);
+
+    for ( it = headerList.begin(),found=false; it != headerList.end()&& !found; ++it )
+    {
+        found=it->contains(QRegExp("^ *X-Generator:.*"));
+        if (found) *it = temp;
+    }
+    if (KDE_ISUNLIKELY( !found ))
+        headerList.append(temp);
+
     //m_header.setMsgstr( headerList.join( "\n" ) );
     header=headerList.join("\n");
 //END header itself
@@ -546,12 +567,7 @@ void updateHeader(QString& header,
 //                        return;
     QStringList foundAuthors;
 
-    temp = "# ";
-    //temp += identityOptions->readEntry("authorName","");
-    temp += Settings::authorName();
-    if (!Settings::authorEmail().isEmpty())
-        temp+=(" <"+Settings::authorEmail()+'>');
-    temp+=", "+QDate::currentDate().toString("yyyy")+'.';
+    temp="# "%authorNameEmail%", "%QDate::currentDate().toString("yyyy")%'.';
 
     // ### TODO: it would be nice if the entry could start with "COPYRIGHT" and have the "(C)" symbol (both not mandatory)
     QRegExp regexpAuthorYear( "^#.*(<.+@.+>)?,\\s*([\\d]+[\\d\\-, ]*|YEAR)" );
@@ -611,15 +627,23 @@ void updateHeader(QString& header,
             ait = foundAuthors.end();
             for ( it = foundAuthors.begin() ; it!=foundAuthors.end(); ++it )
             {
-                if ( it->contains( QRegExp(
-                                      QRegExp::escape( Settings::authorName() )+".*"
-                                      + QRegExp::escape( Settings::authorEmail() ) ) )  )
+                bool containsAuthorEmail = it->contains(Settings::authorEmail());
+                if ( it->contains(Settings::authorName()) || containsAuthorEmail )
                 {
                     foundAuthor = true;
                     if ( it->contains( cy ) )
                         found = true;
                     else
                         ait = it;
+
+                    if (!containsAuthorEmail)
+                    {
+                        //update mail
+                        QRegExp mre("<([^>]*)>");
+                        const int mail_pos = mre.lastIndexIn( *it );
+                        if ( mail_pos != -1 && Settings::authorEmail() != mre.cap(1) )
+                            it->replace(mail_pos+1, mre.matchedLength()-2, Settings::authorEmail());
+                    }
                 }
             }
             if ( !found )
@@ -631,9 +655,9 @@ void updateHeader(QString& header,
                     //update years
                     const int index = (*ait).lastIndexOf( QRegExp("[\\d]+[\\d\\-, ]*") );
                     if ( index == -1 )
-                        (*ait)+=", "+cy;
+                        (*ait)+=", "%cy;
                     else
-                        ait->insert(index+1, QString(", ")+cy);
+                        ait->insert(index+1, ", "%cy);
                 }
                 else
                     kDebug() << "INTERNAL ERROR: author found but iterator dangling!";
@@ -644,11 +668,11 @@ void updateHeader(QString& header,
             foundAuthors.append(temp);
 
 
-        foreach (QString s, foundAuthors)
+        foreach (QString author, foundAuthors)
         {
             // ensure dot at the end of copyright
-            if ( !s.endsWith('.') ) s += '.';
-            commentList.append(s);
+            if ( !author.endsWith('.') ) author += '.';
+            commentList.append(author);
         }
     }
 
