@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -19,22 +19,21 @@ namespace Uml
 {
     class CmdMoveWidget : public QUndoCommand
     {
-        public:
-            CmdMoveWidget(UMLWidgetController* wc);
-            ~CmdMoveWidget();
+    public:
+        CmdMoveWidget(UMLWidgetController* wc);
+        ~CmdMoveWidget();
 
-            void redo();
-            void undo();
+        void redo();
+        void undo();
 
-            bool mergeWith(const QUndoCommand* other);
+        // bool mergeWith(const QUndoCommand* other);
 
-        private:
-            UMLWidgetController*    m_widgetCtrl;
-            int         m_x;
-            int         m_y;
-            int         m_oldX;
-            int         m_oldY;
-            bool        m_already;
+    private:
+        UMLWidgetController*    m_widgetCtrl;
+        int         m_x;
+        int         m_y;
+        int         m_oldX;
+        int         m_oldY;
 
     };
 }
