@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2010                                               *
+ *   copyright (C) 2004-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -13,6 +13,7 @@
 #include "codegenerator.h"
 
 // app includes
+#include "debug_utils.h"
 #include "overwritedialogue.h"
 #include "codeviewerdialog.h"
 #include "simplecodegenerator.h"
@@ -28,10 +29,8 @@
 #include "umlobject.h"
 #include "umlattributelist.h"
 #include "umloperationlist.h"
-#include "model_utils.h"
 
 // kde includes
-#include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kdialog.h>
@@ -39,8 +38,9 @@
 
 // qt includes
 #include <QtCore/QDateTime>
-#include <QtCore/QRegExp>
 #include <QtCore/QDir>
+#include <QtCore/QPointer>
+#include <QtCore/QRegExp>
 #include <QtCore/QTextStream>
 #include <QtXml/QDomDocument>
 #include <QtXml/QDomElement>
@@ -52,21 +52,15 @@
  * Constructor for a code generator.
  */
 CodeGenerator::CodeGenerator()
-  : QObject(UMLApp::app()->getDocument())
+  : m_applyToAllRemaining(true),
+    m_document(UMLApp::app()->document()),
+    m_lastIDIndex(0)
 {
-    initFields();
-}
-
-/**
- * Constructor for a code generator and then initialize it from an XMI element.
- * FIX: hmm. this should be pure virtual so that implemented in sub-class.
- * @param element   an element from an XMI document
- */
-CodeGenerator::CodeGenerator(QDomElement & element)
-  : QObject(UMLApp::app()->getDocument())
-{
-    initFields();
-    loadFromXMI(element);  // hmm. cannot call this here.. it is 'pure' virtual
+    // initial population of our project generator
+    // CANNOT Be done here because we would call pure virtual method
+    // of newClassifierDocument (bad!).
+    // We should only call from the child
+    // initFromParentDocument();
 }
 
 /**
@@ -96,16 +90,16 @@ QString CodeGenerator::getUniqueID(CodeDocument * codeDoc)
     ClassifierCodeDocument * classDoc = dynamic_cast<ClassifierCodeDocument*>(codeDoc);
     if (classDoc) {
         UMLClassifier *c = classDoc->getParentClassifier();
-        id = ID2STR(c->getID()); // this is supposed to be unique already..
+        id = ID2STR(c->id()); // this is supposed to be unique already..
     }
     else {
         QString prefix = "doc";
         QString id = prefix + "_0";
-        int number = lastIDIndex;
+        int number = m_lastIDIndex;
         for ( ; findCodeDocumentByID(id); ++number) {
             id = prefix + '_' + QString::number(number);
         }
-        lastIDIndex = number;
+        m_lastIDIndex = number;
     }
 
     return id;
@@ -199,7 +193,7 @@ void CodeGenerator::loadFromXMI(QDomElement & qElement)
     // look for our particular child element
     QDomNode node = qElement.firstChild();
     QDomElement element = node.toElement();
-    QString langType = Model_Utils::progLangToString( language() );
+    QString langType = Uml::ProgrammingLanguage::toString( language() );
 
     if (qElement.tagName() != "codegenerator"
             || qElement.attribute("language", "UNKNOWN") != langType) {
@@ -244,13 +238,13 @@ void CodeGenerator::loadCodeForOperation(const QString& idStr, const QDomElement
         uDebug() << "found UMLObject for id:" << idStr;
         QString value = codeDocElement.attribute("value", "");
 
-        Uml::Object_Type t = obj->getBaseType();
-        if (t == Uml::ot_Operation) {
+        UMLObject::ObjectType t = obj->baseType();
+        if (t == UMLObject::ot_Operation) {
             UMLOperation *op = static_cast<UMLOperation*>(obj);
             op->setSourceCode(value);
         }
         else {
-            uError() << "sourcecode id " << idStr << " has unexpected type " << t;
+            uError() << "sourcecode id " << idStr << " has unexpected type " << UMLObject::toString(t);
         }
     }
     else {
@@ -263,12 +257,12 @@ void CodeGenerator::loadCodeForOperation(const QString& idStr, const QDomElement
  */
 void CodeGenerator::saveToXMI(QDomDocument & doc, QDomElement & root)
 {
-    QString langType = Model_Utils::progLangToString( language() );
+    QString langType = Uml::ProgrammingLanguage::toString( language() );
     QDomElement docElement = doc.createElement( "codegenerator" );
     docElement.setAttribute("language",langType);
 
     if (dynamic_cast<SimpleCodeGenerator*>(this)) {
-        UMLClassifierList concepts = m_document->getClassesAndInterfaces();
+        UMLClassifierList concepts = m_document->classesAndInterfaces();
         foreach (UMLClassifier *c, concepts) {
             UMLOperationList operations = c->getOpList();
             foreach (UMLOperation *op, operations) {
@@ -278,7 +272,7 @@ void CodeGenerator::saveToXMI(QDomDocument & doc, QDomElement & root)
                     continue;
                 }
                 QDomElement codeElement = doc.createElement("sourcecode");
-                codeElement.setAttribute("id", ID2STR(op->getID()));
+                codeElement.setAttribute("id", ID2STR(op->id()));
                 codeElement.setAttribute("value", code);
                 docElement.appendChild( codeElement );
             }
@@ -315,7 +309,7 @@ void CodeGenerator::initFromParentDocument()
 {
     // Walk through the document converting classifiers into
     // classifier code documents as needed (e.g only if doesn't exist)
-    UMLClassifierList concepts = m_document->getClassesAndInterfaces();
+    UMLClassifierList concepts = m_document->classesAndInterfaces();
     foreach (UMLClassifier *c , concepts) {
         // Doesn't exist? Then build one.
         CodeDocument * codeDoc = findCodeDocumentByClassifier(c);
@@ -343,7 +337,9 @@ void CodeGenerator::syncCodeToDocument()
 // in this 'vanilla' version, we only worry about adding classifier
 // documents
 
-/** These 2 functions check for adding or removing objects to the UMLDocument */
+/**
+ * This function checks for adding objects to the UMLDocument.
+ */
 void CodeGenerator::checkAddUMLObject(UMLObject * obj)
 {
     if (!obj) {
@@ -357,6 +353,9 @@ void CodeGenerator::checkAddUMLObject(UMLObject * obj)
     }
 }
 
+/**
+ * This function checks for removing objects from the UMLDocument.
+ */
 void CodeGenerator::checkRemoveUMLObject(UMLObject * obj)
 {
     if (!obj) {
@@ -372,9 +371,15 @@ void CodeGenerator::checkRemoveUMLObject(UMLObject * obj)
     }
 }
 
+/**
+ * Find a code document by the given classifier.
+ * NOTE: FIX, this should be 'protected' or we could have problems with CPP code generator
+ * @return      CodeDocument
+ * @param       classifier
+ */
 CodeDocument * CodeGenerator::findCodeDocumentByClassifier(UMLClassifier * classifier)
 {
-    return findCodeDocumentByID(ID2STR(classifier->getID()));
+    return findCodeDocumentByID(ID2STR(classifier->id()));
 }
 
 /**
@@ -427,14 +432,16 @@ void CodeGenerator::writeListedCodeDocsToFile(CodeDocumentList * docs)
             QString filename = findFileName(*it);
             // check that we may open that file for writing
             QFile file;
-            if ( openFile(file,filename) ) {
+            if ( openFile(file, filename) ) {
                 QTextStream stream(&file);
                 stream << (*it)->toString() << endl;
                 file.close();
-                codeGenSuccess = true; // we wrote the code OK
+                codeGenSuccess = true; // we wrote the code - OK
+                emit showGeneratedFile(file.fileName());
             }
             else {
-                uWarning() << "Cannot open file :"<<filename<<" for writing ";
+                uWarning() << "Cannot open file :" << file.fileName() << " for writing!";
+                codeGenSuccess = false;
             }
         }
 
@@ -474,7 +481,7 @@ CodeDocument * CodeGenerator::newCodeDocument()
  */
 QString CodeGenerator::getHeadingFile(const QString &file)
 {
-    return UMLApp::app()->getCommonPolicy()->getHeadingFile(file);
+    return UMLApp::app()->commonPolicy()->getHeadingFile(file);
 }
 
 /**
@@ -494,7 +501,7 @@ QString CodeGenerator::getHeadingFile(const QString &file)
  */
 QString CodeGenerator::overwritableName(const QString& name, const QString &extension)
 {
-    CodeGenerationPolicy *pol = UMLApp::app()->getCommonPolicy();
+    CodeGenerationPolicy *pol = UMLApp::app()->commonPolicy();
     QDir outputDirectory = pol->getOutputDirectory();
     QString filename = name + extension;
 
@@ -503,16 +510,17 @@ QString CodeGenerator::overwritableName(const QString& name, const QString &exte
     }
 
     int suffix;
-    OverwriteDialogue overwriteDialog( name, outputDirectory.absolutePath(),
-                                         m_applyToAllRemaining, kapp->activeWindow() );
+    QPointer<OverwriteDialogue> overwriteDialog =
+        new OverwriteDialogue(name, outputDirectory.absolutePath(),
+                              m_applyToAllRemaining, kapp->activeWindow());
     switch (pol->getOverwritePolicy()) {  //if it exists, check the OverwritePolicy we should use
     case CodeGenerationPolicy::Ok:              //ok to overwrite file
         filename = name + extension;
         break;
     case CodeGenerationPolicy::Ask:            //ask if we can overwrite
-        switch(overwriteDialog.exec()) {
+        switch(overwriteDialog->exec()) {
         case KDialog::Yes:  //overwrite file
-            if ( overwriteDialog.applyToAllRemaining() ) {
+            if ( overwriteDialog->applyToAllRemaining() ) {
                 pol->setOverwritePolicy(CodeGenerationPolicy::Ok);
                 filename = name + extension;
             }
@@ -528,7 +536,7 @@ QString CodeGenerator::overwritableName(const QString& name, const QString &exte
                     break;
                 suffix++;
             }
-            if ( overwriteDialog.applyToAllRemaining() ) {
+            if ( overwriteDialog->applyToAllRemaining() ) {
                 pol->setOverwritePolicy(CodeGenerationPolicy::Never);
             }
             else {
@@ -536,16 +544,16 @@ QString CodeGenerator::overwritableName(const QString& name, const QString &exte
             }
             break;
         case KDialog::Cancel: //don't output anything
-            if ( overwriteDialog.applyToAllRemaining() ) {
+            if ( overwriteDialog->applyToAllRemaining() ) {
                 pol->setOverwritePolicy(CodeGenerationPolicy::Cancel);
             }
             else {
                 m_applyToAllRemaining = false;
             }
+            delete overwriteDialog;
             return QString();
             break;
         }
-
         break;
     case CodeGenerationPolicy::Never: //generate similar name
         suffix = 1;
@@ -558,10 +566,12 @@ QString CodeGenerator::overwritableName(const QString& name, const QString &exte
         }
         break;
     case CodeGenerationPolicy::Cancel: //don't output anything
+        delete overwriteDialog;
         return QString();
         break;
     }
 
+    delete overwriteDialog;
     return filename;
 }
 
@@ -581,10 +591,10 @@ bool CodeGenerator::openFile(QFile & file, const QString &fileName)
         return false;
     }
     else {
-        QDir outputDirectory = UMLApp::app()->getCommonPolicy()->getOutputDirectory();
+        QDir outputDirectory = UMLApp::app()->commonPolicy()->getOutputDirectory();
         file.setFileName(outputDirectory.absoluteFilePath(fileName));
         if(!file.open(QIODevice::WriteOnly)) {
-            KMessageBox::sorry(0,i18n("Cannot open file %1 for writing. Please make sure the folder exists and you have permissions to write to it.", file.fileName()),i18n("Cannot Open File"));
+            KMessageBox::sorry(0, i18n("Cannot open file %1 for writing. Please make sure the folder exists and you have permissions to write to it.", file.fileName()), i18n("Cannot Open File"));
             return false;
         }
         return true;
@@ -633,7 +643,7 @@ QString CodeGenerator::findFileName(CodeDocument * codeDocument)
 
     // if a path name exists check the existence of the path directory
     if (!path.isEmpty()) {
-        QDir outputDirectory = UMLApp::app()->getCommonPolicy()->getOutputDirectory();
+        QDir outputDirectory = UMLApp::app()->commonPolicy()->getOutputDirectory();
         QDir pathDir(outputDirectory.absolutePath() + path);
 
         // does our complete output directory exist yet? if not, try to create it
@@ -677,8 +687,8 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
     foreach (UMLAssociation *a , associations) {
         temp = 0;
         switch (a->getAssocType()) {
-        case Uml::at_Generalization:
-        case Uml::at_Realization:
+        case Uml::AssociationType::Generalization:
+        case Uml::AssociationType::Realization:
             // only the "b" end is seen by the "a" end, not other way around
             {
                 UMLObject *objB = a->getObject(Uml::B);
@@ -687,8 +697,8 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
                 }
             }
             break;
-        case Uml::at_Dependency:
-        case Uml::at_UniAssociation:
+        case Uml::AssociationType::Dependency:
+        case Uml::AssociationType::UniAssociation:
             {
                 UMLObject *objA = a->getObject(Uml::A);
                 UMLObject *objB = a->getObject(Uml::B);
@@ -697,18 +707,18 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
                 }
             }
             break;
-        case Uml::at_Aggregation:
-        case Uml::at_Composition:
-        case Uml::at_Association:
+        case Uml::AssociationType::Aggregation:
+        case Uml::AssociationType::Composition:
+        case Uml::AssociationType::Association:
             {
                 UMLObject *objA = a->getObject(Uml::A);
                 UMLObject *objB = a->getObject(Uml::B);
-                if (objA == c && objB->getBaseType() != Uml::ot_Datatype) {
+                if (objA == c && objB->baseType() != UMLObject::ot_Datatype) {
                     temp = static_cast<UMLPackage*>(objB);
                 }
             }
             break;
-        default: /* all others.. like for state diagrams..we currently don't use */
+        default: // all others.. like for state diagrams..we currently don't use
             break;
         }
 
@@ -724,14 +734,14 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
         temp = 0;
         //check return value
         temp = (UMLClassifier*) op->getType();
-        if (temp && temp->getBaseType() != Uml::ot_Datatype && !cList.count(temp)) {
+        if (temp && temp->baseType() != UMLObject::ot_Datatype && !cList.count(temp)) {
             cList.append(temp);
         }
         //check parameters
         UMLAttributeList atl = op->getParmList();
         foreach(UMLAttribute *at , atl) {
             temp = (UMLClassifier*)at->getType();
-            if (temp && temp->getBaseType() != Uml::ot_Datatype && !cList.count(temp)) {
+            if (temp && temp->baseType() != UMLObject::ot_Datatype && !cList.count(temp)) {
                 cList.append(temp);
             }
         }
@@ -743,7 +753,7 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
         foreach (UMLAttribute *at , atl ) {
             temp=0;
             temp = (UMLClassifier*) at->getType();
-            if (temp && temp->getBaseType() != Uml::ot_Datatype && !cList.count(temp)) {
+            if (temp && temp->baseType() != UMLObject::ot_Datatype && !cList.count(temp)) {
                 cList.append(temp);
             }
         }
@@ -761,7 +771,7 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
  */
 QString CodeGenerator::formatDoc(const QString &text, const QString &linePrefix, int lineWidth)
 {
-    const QString endLine = UMLApp::app()->getCommonPolicy()->getNewLineEndingChars();
+    const QString endLine = UMLApp::app()->commonPolicy()->getNewLineEndingChars();
     QString output;
     QStringList lines = text.split(endLine);
     for (QStringList::ConstIterator lit = lines.constBegin(); lit != lines.constEnd(); ++lit) {
@@ -792,7 +802,7 @@ QString CodeGenerator::formatDoc(const QString &text, const QString &linePrefix,
  */
 QString CodeGenerator::formatSourceCode(const QString& code, const QString& indentation)
 {
-    const QString endLine = UMLApp::app()->getCommonPolicy()->getNewLineEndingChars();
+    const QString endLine = UMLApp::app()->commonPolicy()->getNewLineEndingChars();
     QString output;
     if (! code.isEmpty()) {
         QStringList lines = code.split(endLine);
@@ -803,19 +813,6 @@ QString CodeGenerator::formatSourceCode(const QString& code, const QString& inde
     return output;
 }
 
-void CodeGenerator::initFields()
-{
-    m_document = UMLApp::app()->getDocument();
-    m_applyToAllRemaining = true;
-    lastIDIndex = 0;
-
-    // initial population of our project generator
-    // CANT Be done here because we would call pure virtual method
-    // of newClassifierDocument (bad!).
-    // We should only call from the child
-    // initFromParentDocument();
-}
-
 /**
  * Connect additional slots.
  * Only required for Advanced Code Generators.
@@ -827,7 +824,7 @@ void CodeGenerator::connect_newcodegen_slots()
             this, SLOT(checkAddUMLObject(UMLObject*)));
     connect(m_document, SIGNAL(sigObjectRemoved(UMLObject*)),
             this, SLOT(checkRemoveUMLObject(UMLObject*)));
-    CodeGenerationPolicy *commonPolicy = UMLApp::app()->getCommonPolicy();
+    CodeGenerationPolicy *commonPolicy = UMLApp::app()->commonPolicy();
     connect(commonPolicy, SIGNAL(modifiedCodeContent()),
             this, SLOT(syncCodeToDocument()));
 }
@@ -838,22 +835,22 @@ void CodeGenerator::connect_newcodegen_slots()
 
 void CodeGenerator::setForceDoc(bool f)
 {
-    UMLApp::app()->getCommonPolicy()->setCodeVerboseDocumentComments(f);
+    UMLApp::app()->commonPolicy()->setCodeVerboseDocumentComments(f);
 }
 
 bool CodeGenerator::forceDoc() const
 {
-    return UMLApp::app()->getCommonPolicy()->getCodeVerboseDocumentComments();
+    return UMLApp::app()->commonPolicy()->getCodeVerboseDocumentComments();
 }
 
 void CodeGenerator::setForceSections(bool f)
 {
-    UMLApp::app()->getCommonPolicy()->setCodeVerboseSectionComments(f);
+    UMLApp::app()->commonPolicy()->setCodeVerboseSectionComments(f);
 }
 
 bool CodeGenerator::forceSections() const
 {
-    return UMLApp::app()->getCommonPolicy()->getCodeVerboseSectionComments();
+    return UMLApp::app()->commonPolicy()->getCodeVerboseSectionComments();
 }
 
 /**
