@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -18,16 +18,16 @@
 #include <QResizeEvent>
 #include <QtGui/QPainter>
 //kde includes
-#include <kdebug.h>
 #include <kcursor.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 
 //app includes
+#include "classifier.h"
+#include "debug_utils.h"
 #include "messagewidgetcontroller.h"
 #include "floatingtextwidget.h"
 #include "objectwidget.h"
-#include "classifier.h"
 #include "operation.h"
 #include "umlview.h"
 #include "umldoc.h"
@@ -35,10 +35,21 @@
 #include "uniqueid.h"
 #include "listpopupmenu.h"
 
-MessageWidget::MessageWidget(UMLView * view, ObjectWidget* a, ObjectWidget* b,
+/**
+ * Constructs a MessageWidget.
+ *
+ * @param scene   The parent to this class.
+ * @param a       The role A widget for this message.
+ * @param b       The role B widget for this message.
+ * @param y       The vertical position to display this message.
+ * @param sequenceMessageType Whether synchronous or asynchronous
+ * @param id      A unique id used for deleting this object cleanly.
+ *                The default (-1) will prompt generation of a new ID.
+ */
+MessageWidget::MessageWidget(UMLScene * scene, ObjectWidget* a, ObjectWidget* b,
                              int y, Uml::Sequence_Message_Type sequenceMessageType,
                              Uml::IDType id /* = Uml::id_None */)
-  : UMLWidget(view, id, new MessageWidgetController(this))
+  : UMLWidget(scene, WidgetBase::wt_Message, id, new MessageWidgetController(this))
 {
     init();
     m_pOw[Uml::A] = a;
@@ -58,15 +69,35 @@ MessageWidget::MessageWidget(UMLView * view, ObjectWidget* a, ObjectWidget* b,
     this->activate();
 }
 
-MessageWidget::MessageWidget(UMLView * view, Uml::Sequence_Message_Type seqMsgType, Uml::IDType id)
-  : UMLWidget(view, id, new MessageWidgetController(this))
+/**
+ * Constructs a MessageWidget.
+ *
+ * @param scene              The parent to this class.
+ * @param sequenceMessageType The Uml::Sequence_Message_Type of this message widget
+ * @param id                The ID to assign (-1 will prompt a new ID.)
+ */
+MessageWidget::MessageWidget(UMLScene * scene, Uml::Sequence_Message_Type seqMsgType,
+                             Uml::IDType id)
+  : UMLWidget(scene, WidgetBase::wt_Message, id, new MessageWidgetController(this))
 {
     init();
     m_sequenceMessageType = seqMsgType;
 }
 
-MessageWidget::MessageWidget(UMLView * view, ObjectWidget* a, int xclick, int yclick, Uml::Sequence_Message_Type sequenceMessageType, Uml::IDType id /*= Uml::id_None*/)
-  : UMLWidget(view, id, new MessageWidgetController(this))
+/**
+ * Constructs a Lost or Found MessageWidget.
+ *
+ * @param scene  The parent to this class.
+ * @param a      The role A widget for this message.
+ * @param xclick The horizontal position clicked by the user
+ * @param yclick The vertical position clicked by the user
+ * @param sequenceMessageType Whether lost or found
+ * @param id     The ID to assign (-1 will prompt a new ID.)
+ */
+MessageWidget::MessageWidget(UMLScene * scene, ObjectWidget* a, int xclick, int yclick,
+                             Uml::Sequence_Message_Type sequenceMessageType,
+                             Uml::IDType id /*= Uml::id_None*/)
+  : UMLWidget(scene, WidgetBase::wt_Message, id, new MessageWidgetController(this))
 {
     init();
     m_pOw[Uml::A] = a;
@@ -89,17 +120,22 @@ MessageWidget::MessageWidget(UMLView * view, ObjectWidget* a, int xclick, int yc
     this->activate();
 }
 
+/**
+ * Initializes key variables of the class.
+ */
 void MessageWidget::init()
 {
-    UMLWidget::setBaseType(Uml::wt_Message);
-    m_bIgnoreSnapToGrid = true;
-    m_bIgnoreSnapComponentSizeToGrid = true;
+    m_ignoreSnapToGrid = true;
+    m_ignoreSnapComponentSizeToGrid = true;
     m_pOw[Uml::A] = m_pOw[Uml::B] = NULL;
     m_pFText = NULL;
     m_nY = 0;
     setVisible(true);
 }
 
+/**
+ * Standard destructor.
+ */
 MessageWidget::~MessageWidget()
 {
 }
@@ -108,12 +144,12 @@ void MessageWidget::updateResizability()
 {
     if (m_sequenceMessageType == Uml::sequence_message_synchronous ||
         m_pOw[Uml::A] == m_pOw[Uml::B])
-        UMLWidget::m_bResizable = true;
+        UMLWidget::m_resizable = true;
     else
-        UMLWidget::m_bResizable = false;
+        UMLWidget::m_resizable = false;
 }
 
-void MessageWidget::draw(QPainter& p, int offsetX, int offsetY)
+void MessageWidget::paint(QPainter& p, int offsetX, int offsetY)
 {
     if(!m_pOw[Uml::A] || !m_pOw[Uml::B]) {
         return;
@@ -219,7 +255,7 @@ void MessageWidget::drawSynchronous(QPainter& p, int offsetX, int offsetY)
         drawArrow(p, offsetX + 18, offsetY + h - 3, w - 18, Qt::RightArrow, true); // return arrow
     }
 
-    if(m_bSelected) {
+    if(m_selected) {
         drawSelected(&p, offsetX, offsetY);
     }
 }
@@ -264,7 +300,7 @@ void MessageWidget::drawAsynchronous(QPainter& p, int offsetX, int offsetY)
         drawArrow(p, offsetX, offsetY + 4, w, Qt::LeftArrow);
     }
 
-    if (m_bSelected)
+    if (m_selected)
         drawSelected(&p, offsetX, offsetY);
 }
 
@@ -294,7 +330,7 @@ void MessageWidget::drawCreation(QPainter& p, int offsetX, int offsetY)
         drawArrow(p, offsetX, lineY, w, Qt::LeftArrow);
     }
 
-    if (m_bSelected)
+    if (m_selected)
         drawSelected(&p, offsetX, offsetY);
 }
 
@@ -333,7 +369,7 @@ void MessageWidget::drawLost(QPainter& p, int offsetX, int offsetY)
         drawArrow(p, offsetX + h, offsetY, w - h, Qt::LeftArrow);
     }
 
-    if (m_bSelected)
+    if (m_selected)
         drawSelected(&p, offsetX, offsetY);
 }
 
@@ -369,7 +405,7 @@ void MessageWidget::drawFound(QPainter& p, int offsetX, int offsetY)
         drawArrow(p, x2, offsetY, w, Qt::RightArrow);
     }
 
-    if (m_bSelected)
+    if (m_selected)
             drawSelected(&p, offsetX, offsetY);
 
 }
@@ -396,6 +432,9 @@ int MessageWidget::onWidget(const QPoint & p)
     return 1;
 }
 
+/**
+ * Sets the text position relative to the sequence message.
+ */
 void MessageWidget::setTextPosition()
 {
     if (m_pFText == NULL) {
@@ -412,11 +451,11 @@ void MessageWidget::setTextPosition()
     m_pFText->setY( ftY );
 }
 
-int MessageWidget::constrainX(int textX, int textWidth, Uml::Text_Role tr)
+int MessageWidget::constrainX(int textX, int textWidth, Uml::TextRole tr)
 {
     int result = textX;
     const int minTextX = getX() + 5;
-    if (textX < minTextX || tr == Uml::tr_Seq_Message_Self) {
+    if (textX < minTextX || tr == Uml::TextRole::Seq_Message_Self) {
         result = minTextX;
     } else {
         ObjectWidget *objectAtRight = NULL;
@@ -434,8 +473,18 @@ int MessageWidget::constrainX(int textX, int textWidth, Uml::Text_Role tr)
     return result;
 }
 
+/**
+ * Constrains the FloatingTextWidget X and Y values supplied.
+ * Overrides operation from LinkWidget.
+ *
+ * @param textX             Candidate X value (may be modified by the constraint.)
+ * @param textY             Candidate Y value (may be modified by the constraint.)
+ * @param textWidth Width of the text.
+ * @param textHeight        Height of the text.
+ * @param tr                Uml::Text_Role of the text.
+ */
 void MessageWidget::constrainTextPos(int &textX, int &textY, int textWidth, int textHeight,
-                                     Uml::Text_Role tr)
+                                     Uml::TextRole tr)
 {
     textX = constrainX(textX, textWidth, tr);
     // Constrain Y.
@@ -463,7 +512,7 @@ void MessageWidget::moveEvent(QMoveEvent* /*m*/)
         return;
     }
     //TODO why this condition?
-/*    if (m_pView->getSelectCount() > 2) {
+/*    if (m_scene->getSelectCount() > 2) {
         return;
     }*/
 
@@ -504,7 +553,7 @@ void MessageWidget::slotWidgetMoved(Uml::IDType id)
     calculateWidget();
     if( !m_pFText )
         return;
-    if (m_pView->getSelectCount(true) > 1)
+    if (m_scene->getSelectCount(true) > 1)
         return;
     setTextPosition();
 }
@@ -519,10 +568,10 @@ bool MessageWidget::contains(ObjectWidget * w)
 
 void MessageWidget::slotMenuSelection(QAction* action)
 {
-    ListPopupMenu::Menu_Type sel = m_pMenu->getMenuType(action);
+    ListPopupMenu::MenuType sel = m_pMenu->getMenuType(action);
     if(sel == ListPopupMenu::mt_Delete) {
         // This will clean up this widget and the text widget:
-        m_pView -> removeWidget(this);
+        m_scene -> removeWidget(this);
     } else {
 
         UMLWidget::slotMenuSelection( action );
@@ -531,10 +580,10 @@ void MessageWidget::slotMenuSelection(QAction* action)
 
 bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
 {
-    m_pView->resetPastePoint();
+    m_scene->resetPastePoint();
     // UMLWidget::activate(Log);   CHECK: I don't think we need this ?
     if (m_pOw[Uml::A] == NULL) {
-        UMLWidget *pWA = m_pView->findWidget(m_widgetAId);
+        UMLWidget *pWA = m_scene->findWidget(m_widgetAId);
         if (pWA == NULL) {
             uDebug() << "role A object " << ID2STR(m_widgetAId) << " not found";
             return false;
@@ -547,7 +596,7 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
         }
     }
     if (m_pOw[Uml::B] == NULL) {
-        UMLWidget *pWB = m_pView->findWidget(m_widgetBId);
+        UMLWidget *pWB = m_scene->findWidget(m_widgetBId);
         if (pWB == NULL) {
             uDebug() << "role B object " << ID2STR(m_widgetBId) << " not found";
             return false;
@@ -574,10 +623,10 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
     }
 
     if( !m_pFText ) {
-        Uml::Text_Role tr = Uml::tr_Seq_Message;
+        Uml::TextRole tr = Uml::TextRole::Seq_Message;
         if (m_pOw[Uml::A] == m_pOw[Uml::B])
-            tr = Uml::tr_Seq_Message_Self;
-        m_pFText = new FloatingTextWidget( m_pView, tr, "" );
+            tr = Uml::TextRole::Seq_Message_Self;
+        m_pFText = new FloatingTextWidget( m_scene, tr, "" );
         m_pFText->setFont(UMLWidget::font());
     }
     if (op)
@@ -601,43 +650,78 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
     return true;
 }
 
+/**
+ * Overrides operation from LinkWidget.
+ * Required by FloatingTextWidget.
+ *
+ * @param ft   The text widget which to update.
+ */
 void MessageWidget::setMessageText(FloatingTextWidget *ft)
 {
     if (ft == NULL)
         return;
-    QString displayText = m_SequenceNumber + ": " + getOperationText(m_pView);
+    QString displayText = m_SequenceNumber + ": " + operationText(m_scene);
     ft->setText(displayText);
     setTextPosition();
 }
 
+/**
+ * Overrides operation from LinkWidget.
+ * Required by FloatingTextWidget.
+ *
+ * @param ft        The text widget which to update.
+ * @param newText   The new text to set.
+ */
 void MessageWidget::setText(FloatingTextWidget *ft, const QString &newText)
 {
     ft->setText(newText);
-    UMLApp::app()->getDocument()->setModified(true);
+    UMLApp::app()->document()->setModified(true);
 }
 
+/**
+ * Overrides operation from LinkWidget.
+ * Required by FloatingTextWidget.
+ *
+ * @param seqNum    The new sequence number string to set.
+ * @param op        The new operation string to set.
+ */
 void MessageWidget::setSeqNumAndOp(const QString &seqNum, const QString &op)
 {
     setSequenceNumber( seqNum );
     m_CustomOp = op;   ///FIXME m_pOperation
 }
 
-void MessageWidget::setSequenceNumber( const QString &sequenceNumber )
+/**
+ * Write property of QString m_SequenceNumber.
+ */
+void MessageWidget::setSequenceNumber(const QString &sequenceNumber)
 {
     m_SequenceNumber = sequenceNumber;
 }
 
-QString MessageWidget::getSequenceNumber() const
+/**
+ * Read property of QString m_SequenceNumber.
+ */
+QString MessageWidget::sequenceNumber() const
 {
     return m_SequenceNumber;
 }
 
+/**
+ * Implements operation from LinkWidget.
+ * Required by FloatingTextWidget.
+ */
 void MessageWidget::lwSetFont (QFont font)
 {
     UMLWidget::setFont( font );
 }
 
-UMLClassifier *MessageWidget::getOperationOwner()
+/**
+ * Overrides operation from LinkWidget.
+ * Required by FloatingTextWidget.
+ * @todo Move to LinkWidget.
+ */
+UMLClassifier *MessageWidget::operationOwner()
 {
     UMLObject *pObject = m_pOw[Uml::B]->umlObject();
     if (pObject == NULL)
@@ -646,11 +730,19 @@ UMLClassifier *MessageWidget::getOperationOwner()
     return c;
 }
 
-UMLOperation *MessageWidget::getOperation()
+/**
+ * Implements operation from LinkWidget.
+ * Motivated by FloatingTextWidget.
+ */
+UMLOperation *MessageWidget::operation()
 {
     return static_cast<UMLOperation*>(m_pObject);
 }
 
+/**
+ * Implements operation from LinkWidget.
+ * Motivated by FloatingTextWidget.
+ */
 void MessageWidget::setOperation(UMLOperation *op)
 {
     if (m_pObject && m_pFText)
@@ -660,23 +752,31 @@ void MessageWidget::setOperation(UMLOperation *op)
         connect(m_pObject, SIGNAL(modified()), m_pFText, SLOT(setMessageText()));
 }
 
-QString MessageWidget::getCustomOpText()
+/**
+ * Overrides operation from LinkWidget.
+ * Required by FloatingTextWidget.
+ */
+QString MessageWidget::customOpText()
 {
     return m_CustomOp;
 }
 
+/**
+ * Overrides operation from LinkWidget.
+ * Required by FloatingTextWidget.
+ */
 void MessageWidget::setCustomOpText(const QString &opText)
 {
     m_CustomOp = opText;
     m_pFText->setMessageText();
 }
 
-UMLClassifier * MessageWidget::getSeqNumAndOp(QString& seqNum, QString& op)
+UMLClassifier * MessageWidget::seqNumAndOp(QString& seqNum, QString& op)
 {
     seqNum = m_SequenceNumber;
-    UMLOperation *pOperation = getOperation();
+    UMLOperation *pOperation = operation();
     if (pOperation != NULL) {
-        op = pOperation->toString(Uml::st_SigNoVis);
+        op = pOperation->toString(Uml::SignatureType::SigNoVis);
     } else {
         op = m_CustomOp;
     }
@@ -700,7 +800,7 @@ void MessageWidget::calculateDimensions()
     } else {
         uWarning() << "Unknown message type";
     }
-    if (! UMLApp::app()->getDocument()->loading()) {
+    if (! UMLApp::app()->document()->loading()) {
         adjustAssocs( getX(), getY() );  // adjust assoc lines
     }
 }
@@ -863,7 +963,7 @@ void MessageWidget::cleanup()
 
     UMLWidget::cleanup();
     if (m_pFText) {
-        m_pView->removeWidget(m_pFText);
+        m_scene->removeWidget(m_pFText);
         m_pFText = NULL;
     }
 }
@@ -873,13 +973,13 @@ void MessageWidget::setSelected(bool _select)
     UMLWidget::setSelected( _select );
     if( !m_pFText || m_pFText->displayText().isEmpty())
         return;
-    if( m_bSelected && m_pFText -> getSelected() )
+    if( m_selected && m_pFText -> getSelected() )
         return;
-    if( !m_bSelected && !m_pFText -> getSelected() )
+    if( !m_selected && !m_pFText -> getSelected() )
         return;
 
-    m_pView -> setSelected( m_pFText, 0 );
-    m_pFText -> setSelected( m_bSelected );
+    m_scene -> setSelected( m_pFText, 0 );
+    m_pFText -> setSelected( m_selected );
 }
 
 int MessageWidget::getMinY()
@@ -913,13 +1013,24 @@ int MessageWidget::getMaxY()
     return (height - this->height());
 }
 
-void MessageWidget::setWidget(ObjectWidget * ow, Uml::Role_Type role)
+/**
+ * Sets the related widget on the given side.
+ *
+ * @param ow     The ObjectWidget we are related to.
+ * @param role   The Uml::Role_Type to be set for the ObjectWidget
+ */
+void MessageWidget::setObjectWidget(ObjectWidget * ow, Uml::Role_Type role)
 {
     m_pOw[role] = ow;
     updateResizability();
 }
 
-ObjectWidget* MessageWidget::getWidget(Uml::Role_Type role)
+/**
+ * Returns the related widget on the given side.
+ *
+ * @return  The ObjectWidget we are related to.
+ */
+ObjectWidget* MessageWidget::objectWidget(Uml::Role_Type role)
 {
     return m_pOw[role];
 }
@@ -941,15 +1052,18 @@ void MessageWidget::setyclicked (int yclick)
 //     UMLWidget::setSize(width,height);
 // }
 
-void MessageWidget::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
+/**
+ * Saves to the "messagewidget" XMI element.
+ */
+void MessageWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
 {
     QDomElement messageElement = qDoc.createElement( "messagewidget" );
     UMLWidget::saveToXMI( qDoc, messageElement );
     messageElement.setAttribute( "widgetaid", ID2STR(m_pOw[Uml::A]->localID()) );
     messageElement.setAttribute( "widgetbid", ID2STR(m_pOw[Uml::B]->localID()) );
-    UMLOperation *pOperation = getOperation();
+    UMLOperation *pOperation = operation();
     if (pOperation)
-        messageElement.setAttribute( "operation", ID2STR(pOperation->getID()) );
+        messageElement.setAttribute( "operation", ID2STR(pOperation->id()) );
     else
         messageElement.setAttribute( "operation", m_CustomOp );
     messageElement.setAttribute( "seqnum", m_SequenceNumber );
@@ -968,6 +1082,9 @@ void MessageWidget::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
     qElement.appendChild( messageElement );
 }
 
+/**
+ * Loads from the "messagewidget" XMI element.
+ */
 bool MessageWidget::loadFromXMI(QDomElement& qElement)
 {
     if ( !UMLWidget::loadFromXMI(qElement) ) {
@@ -989,9 +1106,9 @@ bool MessageWidget::loadFromXMI(QDomElement& qElement)
     m_widgetBId = STR2ID(widgetbid);
     m_textId = STR2ID(textid);
 
-    Uml::Text_Role tr = Uml::tr_Seq_Message;
+    Uml::TextRole tr = Uml::TextRole::Seq_Message;
     if (m_widgetAId == m_widgetBId)
-        tr = Uml::tr_Seq_Message_Self;
+        tr = Uml::TextRole::Seq_Message_Self;
 
     //now load child elements
     QDomNode node = qElement.firstChild();
@@ -999,7 +1116,7 @@ bool MessageWidget::loadFromXMI(QDomElement& qElement)
     if ( !element.isNull() ) {
         QString tag = element.tagName();
         if (tag == "floatingtext") {
-            m_pFText = new FloatingTextWidget( m_pView, tr, getOperationText(m_pView), m_textId );
+            m_pFText = new FloatingTextWidget( m_scene, tr, operationText(m_scene), m_textId );
             if( ! m_pFText->loadFromXMI(element) ) {
                 // Most likely cause: The FloatingTextWidget is empty.
                 delete m_pFText;
